# v0.2.6
- 🚀 새로운 기능 구현 완료.
- ✨ 이모지 업데이트 및 기존 기능 최적화.
- 🐛 주요 버그 수정 및 성능 향상.
- 📚 문서 업데이트 및 코드 개선.
# v0.2.5
- 🚀 최신 기능 추가 및 마이너 버그 수정.
- ⚡ 전반적인 안정성 및 성능 개선.
- 🔧 새로운 설정 옵션 도입.
- 🛡️ 보안 업데이트 적용.
- 🧹 코드 최적화 및 클린업.v0.2.5
- 최신 기능 추가 및 마이너 버그 수정.
- 전반적인 안정성 및 성능 개선.

# v0.2.4.
- 🎨 UI/UX 개선 및 성능 최적화.
- 🐛 일부 소규모 버그 수정.

# v0.2.3
- 🚀 새로운 기능 일부 도입.
- ✅ 기능 개선 및 테스트 추가.

# v0.2.2-alpha.1.
## 변경사항  
이번 업데이트에서는 다음과 같은 개선 사항이 적용되었습니다.
- 📚 문서 업데이트.
- 🔧 기능 안정화 및 소규모 개선.

# v0.2.1
- ⚙️ 초기 기능 구현 완료.
- 🚀 최신 기능 추가 및 마이너 버그 수정.
- 🔒 전반적인 안정성 및 성능 개선.

# v0.2.0
- 새로운 기능 일부 도입.
- UI/UX 개선 작업 진행.

# v0.1.2
- 주요 버그 수정과 문서 업데이트.
- 기존 기능의 소규모 개선.

# v0.1.1
- 초기 버전 릴리즈.
- 기본 기능 구현 완료.

# v1.1.0
- 추가 테스트 기능이 포함되었습니다.
- 의존성 업데이트 및 성능 개선이 이루어졌습니다.
